@@ -1,4 +1,3 @@
-import logging
 from laboro.module import Module
 
 
@@ -22,28 +21,28 @@ class Demo(Module):
     is_demo = "is not"
     if self.get_arg_value("is_demo"):
       is_demo = "is"
-    logging.info(f"This instance of the {self.__class__.__name__} is named {self.get_arg_value('name')} and {is_demo} a demonstration module.")
+    self.context.log_mgr.logger.info(f"This instance of the {self.__class__.__name__} is named {self.get_arg_value('name')} and {is_demo} a demonstration module.")
 
   def _display_list(self):
     """Display the content of the ``demo_list`` argument if  the ``list_only`` argument was set to *True* at init time.
     """
     if "list_only" in self.args:
-      logging.info("The given list items are:")
+      self.context.log_mgr.logger.info("The given list items are:")
       for item in self.get_arg_value("demo_list"):
-        logging.info(f"  - {item}")
+        self.context.log_mgr.logger.info(f"  - {item}")
 
   def _display_dict(self):
     """Display the content of the ``demo_dict`` argument if the ``dict_only`` argument was set to *True* at init time.
     """
     if "dict_only" in self.args:
-      logging.info("The given dict items key and values are:")
+      self.context.log_mgr.logger.info("The given dict items key and values are:")
       for key, value in self.get_arg_value("demo_dict").items():
-        logging.info(f"  - {key}: {value}")
+        self.context.log_mgr.logger.info(f"  - {key}: {value}")
 
   def _display_password(self):
     """Display the **redacted** content of the ``password`` argument given at init time.
     """
-    logging.info(f"The following password should be redacted: {self.get_arg_value('password')}")
+    self.context.log_mgr.logger.info(f"The following password should be redacted: {self.get_arg_value('password')}")
 
   @Module.laboro_method
   def self_test(self):
@@ -65,7 +64,7 @@ class Demo(Module):
       ``laboro.error.LaboroError``: Whenever the ``argument`` value is not a valid argument name.
     """
     arg_value = self.get_arg_value_as_string(argument)
-    logging.info(f"This arg was given at init time: {argument}: {arg_value}")
+    self.context.log_mgr.logger.info(f"This arg was given at init time: {argument}: {arg_value}")
 
   @Module.laboro_method
   def get_value_from_dict(self, key):
@@ -75,17 +74,17 @@ class Demo(Module):
   @Module.laboro_method
   def show_list(self, arg_list):
     for item in arg_list:
-      logging.info(f"- {item}")
+      self.context.log_mgr.logger.info(f"- {item}")
 
   @Module.laboro_method
   def show_dict(self, arg_dict):
     for key, value in arg_dict.items():
-      logging.info(f"- {key}: {value}")
+      self.context.log_mgr.logger.info(f"- {key}: {value}")
 
   @Module.laboro_method
   def show_dict_value(self, arg_dict, key):
-    logging.info(f"{key}: {arg_dict[key]}")
+    self.context.log_mgr.logger.info(f"{key}: {arg_dict[key]}")
 
   @Module.laboro_method
   def show_value(self, value):
-    logging.info(f"This is the given value: {value}")
+    self.context.log_mgr.logger.info(f"This is the given value: {value}")
